README.md

* Configuration Directory
This folder stores json files configuring the tools used by the MoMo build system.
You will probably have to specify paths to various external tools here so that the MoMo
build scripts can find them.  